@@ -45,11 +45,11 @@ categorical <- function(vismodeldata){
     
     # check if relative
     if(!attr(dat, 'relative')){
-      dat <- dat[, 1:4]
-      dat <- dat/apply(dat, 1, sum)
-      class(dat) <- class(vismodeldata)
-      warning("Quantum catch are not relative, and have been transformed", call.=FALSE)
-      attr(vismodeldata,'relative') <- TRUE
+      #dat <- dat[, 1:4]
+      #dat <- dat/apply(dat, 1, sum)
+      #class(dat) <- class(vismodeldata)
+      warning("Quantum catch are not relative, which may produce unexpected results", call.=FALSE)
+      #attr(vismodeldata,'relative') <- TRUE
     }
     
   }
@@ -69,13 +69,12 @@ categorical <- function(vismodeldata){
     dat <- dat[, 1:4]
     
     if(round(sum(rowSums(dat/apply(dat,1,sum)))) != dim(dat)[1]){
-      dat <- dat/apply(dat, 1, sum)
-      warning('Quantum catch are not relative, and have been transformed', call.=FALSE)
-      attr(vismodeldata,'relative') <- TRUE
+      #dat <- dat/apply(dat, 1, sum)
+      warning("Quantum catch are not relative, which may produce unexpected results", call.=FALSE)
+      #attr(vismodeldata,'relative') <- TRUE
     }
   }
   
-  
   R7p <- dat[, 1]
   R7y <- dat[, 2]
   R8p <- dat[, 3]
@@ -102,7 +101,6 @@ categorical <- function(vismodeldata){
   res.p$category <- sapply(1:nrow(res.p), function(x) colcat(res.p[x,]))
   res.p$r.vec <- sqrt((abs(res.p$x))^2 + (abs(res.p$y)^2))
   
-  
   res <- res.p
   
   class(res) <- c('colspace', 'data.frame')
