@@ -53,7 +53,8 @@
 #' \item \code{'D65'}: standard daylight.
 #' \item \code{'forestshade'} forest shade.
 #' }
-#' @param bkg either a vector containing the background spectra, or one of the options:
+#' @param bkg background spectrum. Note that this will have no effect when \code{vonkries = FALSE}. 
+#' Either a vector containing the spectral data, or one of the options:
 #' \itemize{ 
 #' \item \code{ideal}: homogeneous illuminance of 1 accross all wavelengths (default).
 #' \item \code{'green'}: green foliage.
@@ -142,14 +143,19 @@ vismodel <- function(rspecdata,
 
 wl_index <- which(names(rspecdata)=='wl')
 wl <- rspecdata[,wl_index]
-y <- rspecdata[,-wl_index]
+y <- rspecdata[, -wl_index, drop=FALSE]
+
+# Negative value check
+if(length(y[y < 0]) > 0){
+  warning(paste("The spectral data contain ", length(y[y < 0]), " negative value(s), which may produce unexpected results. Consider using procspec() to correct them."))
+}
 
 # in case rspecdata only has one spectrum
-
-if(is.null(dim(y))){
-  y <- data.frame(rspecdata[,-wl_index])
-  names(y) <- names(rspecdata)[-wl_index]
-  }
+# 01/10/2017: drop=TRUE above should fix it
+#if(is.null(dim(y))){
+#  y <- data.frame(rspecdata[,-wl_index])
+#  names(y) <- names(rspecdata)[-wl_index]
+#  }
 
 visual2 <- try(match.arg(visual), silent = T)
 sens <- vissyst
@@ -198,6 +204,7 @@ if(!inherits(visual2,'try-error')){
 }else{
     S <- visual[,-which(names(visual)=='wl')]
     sens_wl <- visual[,'wl']
+    fullS <- visual
     visual <- 'user-defined'
     }
 
@@ -243,7 +250,7 @@ if(!inherits(bg2,'try-error')){
 if(bg2=='ideal')
   bkg <- rep(1,dim(rspecdata)[1])
   
-# Defining transmission
+# Defining ocular transmission
 
 trdat <- transmissiondata
 
@@ -252,12 +259,18 @@ if(!inherits(tr2,'try-error')){
   if(is.null(trans)) stop('chosen transmission is NULL')
   trans <- trdat[,grep(tr2,names(trdat))]
   }else{
-    bg2 <- 'user-defined'
+    tr2 <- 'user-defined'
     }
 
 if(tr2=='ideal')
   trans <- rep(1,dim(rspecdata)[1])
 
+if(tr2 != 'ideal' & visual == 'user-defined'){
+	if('sensmod' %in% class(fullS))
+		if(attr(fullS,'om'))
+		  warning('The visual system being used appears to already incorporate ocular transmission. Using anything other than trans=',dQuote('ideal'),'means ocular media effects are being applied a second time.', call.=FALSE)
+}
+
 
 # scale background from percentage to proportion
 if(max(bkg) > 1)
